@@ -31,6 +31,9 @@ __PACKAGE__->create_children(qw/
     Net::ISC::DHCPd::Config::Function
     Net::ISC::DHCPd::Config::OptionSpace
     Net::ISC::DHCPd::Config::Option
+    Net::ISC::DHCPd::Config::Key
+    Net::ISC::DHCPd::Config::Group
+    Net::ISC::DHCPd::Config::Block
     Net::ISC::DHCPd::Config::KeyValue
 /);
 
